Method: Buildr::RepositoryArray#+

Defined in:
lib/buildr/packaging/repository_array.rb

#+(urls) ⇒ Object

Concatenation—Returns a new array built by concatenating the two arrays together to produce a third array of standardized URL Hashes.



34
35
36
# File 'lib/buildr/packaging/repository_array.rb', line 34

def +(urls)
  concat(urls)      
end